==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DTCChromeOS;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Settings for third-party signal providers (based on the &#x60;CHROMEOS&#x60; platform)
 */
@ApiModel(description = "Settings for third-party signal providers (based on the `CHROMEOS` platform)")
@JsonPropertyOrder({ DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders.JSON_PROPERTY_DTC })
@JsonTypeName("DeviceAssuranceChromeOSPlatform_allOf_thirdPartySignalProviders")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DTC = "dtc";
    private DTCChromeOS dtc;

    public DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders() {
    }

    public DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders dtc(DTCChromeOS dtc) {

        this.dtc = dtc;
        return this;
    }

    /**
     * Get dtc
     *
     * @return dtc
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DTC)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DTCChromeOS getDtc() {
        return dtc;
    }

    @JsonProperty(JSON_PROPERTY_DTC)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDtc(DTCChromeOS dtc) {
        this.dtc = dtc;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders deviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders = (DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders) o;
        return Objects.equals(this.dtc, deviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders.dtc);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(dtc);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders {\n");
        sb.append("    dtc: ").append(toIndentedString(dtc)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DTCChromeOS;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Settings for third-party signal providers (based on the &#x60;CHROMEOS&#x60; platform)
 */
@ApiModel(description = "Settings for third-party signal providers (based on the `CHROMEOS` platform)")
@JsonPropertyOrder({ DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders.JSON_PROPERTY_DTC })
@JsonTypeName("DeviceAssuranceChromeOSPlatform_allOf_thirdPartySignalProviders")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DTC = "dtc";
    private DTCChromeOS dtc;

    public DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders() {
    }

    public DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders dtc(DTCChromeOS dtc) {

        this.dtc = dtc;
        return this;
    }

    /**
     * Get dtc
     *
     * @return dtc
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DTC)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DTCChromeOS getDtc() {
        return dtc;
    }

    @JsonProperty(JSON_PROPERTY_DTC)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDtc(DTCChromeOS dtc) {
        this.dtc = dtc;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders deviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders = (DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders) o;
        return Objects.equals(this.dtc, deviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders.dtc);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(dtc);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders {\n");
        sb.append("    dtc: ").append(toIndentedString(dtc)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
